(function () {
  "use strict";

  const defaultDuration = 250

  function duration(duration, direction) {
    if (duration) {
      if (typeof duration === 'object') {
        return duration[direction]
      } else {
        return duration
      }
    } else {
      return defaultDuration
    }
  }

  function buildExpandTransition() {

    const expandTransitionComponent = {
      functional: true,
      props: ["duration"],
      render: (createElement, context) => {
        let data = {
          props: {
            name: "expand",
            css: false
          },
          on: {
            beforeEnter(el) {
              el.style.height = 0
              el.style.opacity = 0
            },

            enter(el, done) {
              var elements = [... el.children]
              let height = elements.map(child => child.offsetHeight).reduce((sum, value) => { return sum + value }, 0)
              $(el).animate({height: height, opacity: 1}, duration(context.props.duration, 'enter'), () => {
                el.removeAttribute("style")
                done
              })
            },

            leave(el, done) {
              $(el).animate({height: 0, opacity: 0}, duration(context.props.duration, 'leave'), () => {
                el.remove()
                done
              })
            }
          },

        }
        return createElement('transition', data, context.children)
      }
    }
    return expandTransitionComponent
  }

  if (typeof exports == "object") {
    module.exports = buildExpandTransition()
  } else if (window && window.Vue) {
    var expandTransition = buildExpandTransition()
    Vue.component('expand-transition', expandTransition)
  }
})();