function buildFadeTransition() {
  "use strict";

  const defaultDuration = 250

  function duration(duration, direction) {
    if (duration) {
      if (typeof duration === 'object') {
        return duration[direction]
      } else {
        return duration
      }
    } else {
      return defaultDuration
    }
  }

  const fadeTransitionComponent = {
    functional: true,
    props: ["duration"],
    render: (createElement, context) => {
      let data = {
        props: {
          name: "fade",
          css: false
        },
        on: {
          beforeEnter(el) {
            el.style.opacity = 0
          },

          enter(el, done) {
            $(el).animate({opacity: 1}, duration(context.props.duration, 'enter'), () => {
              el.removeAttribute("style")
              done
            })
          },

          leave(el, done) {
            $(el).animate({opacity: 0}, duration(context.props.duration, 'leave'), () => {
              el.remove()
              done
            })
          }
        },

      }
      return createElement('transition', data, context.children)
    }
  }
  return fadeTransitionComponent
}